@@ -1,5 +1,5 @@
 package My::DemoNoUsage;
-use base qw( CLI::Framework );
+use base qw( CLI::Framework::Application );
 
 use lib 'lib';
 use lib 't/lib';
@@ -15,12 +15,7 @@ sub option_spec {
     )
 }
 
-sub command_map {
-    {
-        tree    => 'CLI::Framework::Command::Tree',
-        a       => 'My::DemoNoUsage::Command::A',
-    }
-}
+sub valid_commands { qw( tree a ) }
 
 #-------
 1;
