@@ -1,5 +1,5 @@
 package My::PerlFunctions;
-use base qw( CLI::Framework );
+use base qw( CLI::Framework::Application );
 
 use strict;
 use warnings;
@@ -14,7 +14,7 @@ sub init {
     my ($self, $opts) = @_;
 
     # Store App's verbose setting where it will be accessible to commands...
-    $self->cache->set( 'verbose' => $opts->{verbose} );
+    $self->session( 'verbose' => $opts->{verbose} );
 
 }
 
@@ -28,11 +28,7 @@ sub usage_text {
     }
 }
 
-sub command_map {
-    summary => 'My::PerlFunctions::Command::Summary',
-    console => 'CLI::Framework::Command::Console',
-    menu    => 'CLI::Framework::Command::Menu',
-}
+sub valid_commands { qw( summary console ) }
 
 #-------
 1;
